SharedPrefs class

Constructors

SharedPrefs({String seedKey = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBool(String key, {bool? defaultValue}) bool?
getDouble(String key, {double? defaultValue}) double?
getInt(String key, {int? defaultValue}) int?
getKey(String key) String
getString(String key, {String? defaultValue}) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<void>
setBool(String key, {required bool data}) Future<void>
setDouble(String key, double value) Future<void>
setInt(String key, int value) Future<void>
setString(String key, String value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() Future<bool>
createInstance() Future<void>